@@ -1,4 +1,4 @@
-python -c '
+py -c '
 import os
 import pkg_resources
 print(os.path.abspath(pkg_resources.resource_filename("pythonpy.completion", "pycompletion.sh")))
